named(8) 맨 페이지 - 윈디하나의 솔라나라

개요

섹션
맨 페이지 이름
검색(S)

named(8)

NAMED(8)                            BIND 9                            NAMED(8)

NAME
       named - Internet domain name server

SYNOPSIS
       named  [  [-4]  |  [-6]  ]  [-c  config-file] [-C] [-d debug-level] [-D
       string] [-E engine-name] [-f] [-g] [-L logfile] [-M option]  [-m  flag]
       [-n #cpus] [-p port] [-s] [-t directory] [-u user] [-v] [-V] ]

DESCRIPTION
       named is a Domain Name System (DNS) server, part of the BIND 9 distrib‐
       ution  from  ISC.  For  more  information on the DNS, see ]8;;https://datatracker.ietf.org/doc/html/rfc1033.html\RFC 1033]8;;\, ]8;;https://datatracker.ietf.org/doc/html/rfc1034.html\RFC
       1034]8;;\, and ]8;;https://datatracker.ietf.org/doc/html/rfc1035.html\RFC 1035]8;;\.

       When invoked without arguments, named reads the  default  configuration
       file /etc/named.conf, reads any initial data, and listens for queries.

OPTIONS
       -4     This  option  tells named to use only IPv4, even if the host ma‐
              chine is capable of IPv6. -4 and -6 are mutually exclusive.

       -6     This option tells named to use only IPv6, even if the  host  ma‐
              chine is capable of IPv4. -4 and -6 are mutually exclusive.

       -c config-file
              This  option tells named to use config-file as its configuration
              file instead of the default, /etc/named.conf. To ensure that the
              configuration file can be reloaded after the server has  changed
              its  working  directory due to to a possible directory option in
              the configuration file, config-file should be an absolute  path‐
              name.

       -C     This  option  prints  out the default built-in configuration and
              exits.

              NOTE: This is for debugging purposes only and is not an accurate
              representation of the actual configuration used by named at run‐
              time.

       -d debug-level
              This option sets the daemon's debug level to debug-level. Debug‐
              ging traces from named become more verbose as  the  debug  level
              increases.

       -D string
              This  option  specifies  a string that is used to identify a in‐
              stance of named in a process listing. The contents of string are
              not examined.

       -E engine-name
              When applicable, this option specifies the hardware to  use  for
              cryptographic  operations,  such  as a secure key store used for
              signing.

              When BIND 9 is built with OpenSSL, this needs to be set  to  the
              OpenSSL engine identifier that drives the cryptographic acceler‐
              ator or hardware service module (usually pkcs11).

       -f     This option runs the server in the foreground (i.e., do not dae‐
              monize).

       -F     This  options  turns  on FIPS (US Federal Information Processing
              Standards) mode if the underlying crytographic library  supports
              running in FIPS mode.

       -g     This  option  runs  the  server in the foreground and forces all
              logging to stderr.

       -L logfile
              This option sets the log to the file logfile by default, instead
              of the system log.

       -M option
              This option sets the default  (comma-separated)  memory  context
              options. The possible flags are:

              • fill:  fill blocks of memory with tag values when they are al‐
                located or freed, to assist debugging of memory problems; this
                is the implicit default if named has been compiled with  --en‐
                able-developer.

              • nofill:  disable the behavior enabled by fill; this is the im‐
                plicit default unless  named  has  been  compiled  with  --en‐
                able-developer.

       -m flag
              This  option  turns  on  memory  usage debugging flags. Possible
              flags are usage, trace  and  record.  These  correspond  to  the
              ISC_MEM_DEBUGXXXX flags described in <isc/mem.h>.

       -n #cpus
              This  option  creates  #cpus worker threads to take advantage of
              multiple CPUs. If not specified, named tries  to  determine  the
              number  of CPUs present and creates one thread per CPU. If it is
              unable to determine the number of CPUs, a single  worker  thread
              is created.

       -p value
              This  option specifies the port(s) on which the server will lis‐
              ten for queries. If value is of the form <portnum> or dns=<port‐
              num>, the server will listen for DNS queries on portnum; if  not
              not  specified,  the default is port 53. If value is of the form
              tls=<portnum>, the server will listen for TLS queries  on  port‐
              num;  the  default is 853.  If value is of the form https=<port‐
              num>, the server will listen for HTTPS queries on  portnum;  the
              default  is  443.   If  value is of the form http=<portnum>, the
              server will listen for HTTP queries on portnum; the  default  is
              80.

       -s     This option writes memory usage statistics to stdout on exit.

       NOTE:
          This  option  is  mainly of interest to BIND 9 developers and may be
          removed or changed in a future release.

       -t directory
              This option tells named to chroot to directory after  processing
              the command-line arguments, but before reading the configuration
              file.

       WARNING:
          This option should be used in conjunction with the -u option, as ch‐
          rooting  a  process running as root doesn't enhance security on most
          systems; the way chroot is defined allows a process with root privi‐
          leges to escape a chroot jail.

       -U #listeners
              This option has been removed. Attempts to use it now result in a
              warning.

       -u user
              This option sets the setuid to user after completing  privileged
              operations,  such  as creating sockets that listen on privileged
              ports.

       NOTE:
          On Linux, named uses the kernel's capability mechanism to  drop  all
          root  privileges except the ability to bind to a privileged port and
          set process resource limits. Unfortunately, this means that  the  -u
          option  only  works  when named is run on kernel 2.2.18 or later, or
          kernel 2.3.99-pre3 or later, since previous kernels  did  not  allow
          privileges to be retained after setuid.

       -v     This option reports the version number and exits.

       -V     This option reports the version number, build options, supported
              cryptographics algorithms, and exits.

       -X lock-file
              This option has been removed and using it will cause a fatal er‐
              ror.

SIGNALS
       In  routine  operation, signals should not be used to control the name‐
       server; rndc should be used instead.

       SIGHUP This signal forces a reload of the server.

       SIGINT, SIGTERM
              These signals shut down the server.

       The result of sending any other signals to the server is undefined.

CONFIGURATION
       The named configuration file is too complex to describe in detail here.
       A complete description is provided in the BIND 9  Administrator  Refer‐
       ence Manual.

       named  inherits  the  umask  (file  creation mode mask) from the parent
       process. If files created by named, such as journal files, need to have
       custom permissions, the umask should be set explicitly  in  the  script
       used to start the named process.

FILES
       /etc/named.conf
              The default configuration file.

       /var/run/named.pid
              The default process-id file.


ATTRIBUTES
       See attributes(7) for descriptions of the following attributes:

       box; cbp-1 | cbp-1 l | l .  ATTRIBUTE TYPE ATTRIBUTE VALUE = Availabil‐
       ity   network/dns/bind = Stability Pass-through uncommitted

SEE ALSO
       ]8;;https://datatracker.ietf.org/doc/html/rfc1033.html\RFC  1033]8;;\,  ]8;;https://datatracker.ietf.org/doc/html/rfc1034.html\RFC  1034]8;;\,  ]8;;https://datatracker.ietf.org/doc/html/rfc1035.html\RFC  1035]8;;\,  dns-server(8s), named-checkconf(8),
       named-checkzone(8), rndc(8), named.conf(5), BIND 9 Administrator Refer‐
       ence Manual.

       The BIND 9 Administrator's Reference Manual (ARM) is  available  online
       at ]8;;https://bind9.readthedocs.io/en/v9.20.15/\https://bind9.readthedocs.io/en/v9.20.15/]8;;\

       Note

       Some  compile-time features documented in the ARM are not available; to
       see a list of enabled features run /usr/sbin/named -V.

AUTHOR
       Internet Systems Consortium

COPYRIGHT
       2025, Internet Systems Consortium



NOTES
       Source code for open source software components in Oracle  Solaris  can
       be found at https://www.oracle.com/downloads/opensource/solaris-source-
       code-downloads.html.

       This software was built from source available at:
       https://github.com/oracle/solaris-userland

       The original community source was downloaded from:
       http://downloads.isc.org/isc/bind9/9.20.15/bind-9.20.15.tar.xz

       Further information about this software can be found on the open source
       community website at http://www.isc.org/software/bind/.

9.20.15                           2025-10-18                          NAMED(8)
맨 페이지 내용의 저작권은 맨 페이지 작성자에게 있습니다.
RSS ATOM XHTML 5 CSS3